API Documentation
=================

Reference material for public API.

Core classes
------------

.. toctree::
    :maxdepth: 1

    src/api/gaplic
    src/api/gobj
    src/api/smachine
    src/api/gconfig

Essential GObjs.
----------------

.. toctree::
    :maxdepth: 1

    src/api/c_timer
    src/api/c_sock
    src/api/c_srv_sock
    src/api/c_connex
    src/api/c_wsgi_server
